pub struct Mle<F> { /* private fields */ }Expand description
Multilinear extension polynomial, in coefficient form.
Length of coeffs is 2^n where n is hypercube dimension.
Indexing of coeffs is to use the little-endian encoding of integer index as the powers of
variables.
Implementations
Sourceimpl<F: Field> Mle<F>
impl<F: Field> Mle<F>
pub fn from_coeffs(coeffs: Vec<F>) -> Self
Sourcepub fn from_evaluations(evals: &[F]) -> Self
pub fn from_evaluations(evals: &[F]) -> Self
Create MLE from evaluations on the hypercube.
Takes evaluations of the polynomial at all points in {0,1}^n and converts them to coefficient form.
The input evals should have length 2^n where n is the number of variables.
The evaluation at index i corresponds to the point whose binary representation
is i (with bit 0 being the least significant).
pub fn into_coeffs(self) -> Vec<F>
Sourcepub fn eval_at_point<F2: Field, EF: ExtensionField<F> + Mul<F2, Output = EF>>(
&self,
x: &[F2],
) -> EF
pub fn eval_at_point<F2: Field, EF: ExtensionField<F> + Mul<F2, Output = EF>>( &self, x: &[F2], ) -> EF
Evaluate with O(1) extra memory via naive algorithm.
Performs N*log(N)/2 multiplications when N = x.len() is a power of two.
Sourcepub fn eval_at_point_inplace<F2>(self, x: &[F2]) -> Fwhere
F2: Field,
F: ExtensionField<F2>,
pub fn eval_at_point_inplace<F2>(self, x: &[F2]) -> Fwhere
F2: Field,
F: ExtensionField<F2>,
Evaluate with O(1) extra memory but consuming self.
Performs N - 1 multiplications for N = x.len().
pub fn evals_to_coeffs_inplace(a: &mut [F])
pub fn coeffs_to_evals_inplace(a: &mut [F])