pub struct Ple<F> { /* private fields */ }Expand description
Prismalinear extension polynomial, in coefficient form.
Depends on implicit univariate skip parameter l_skip.
Length of coeffs is 2^{l_skip + n} where n is hypercube dimension.
Indexing is to decompose i = i_0 + 2^{l_skip} * (i_1 + 2 * i_2 .. + 2^{n-1} * i_n) and let
coeffs[i] be the coefficient of Z^{i_0} X_1^{i_1} .. X_n^{i_n}.
Implementations
Sourceimpl<F: TwoAdicField> Ple<F>
impl<F: TwoAdicField> Ple<F>
Sourcepub fn from_evaluations(l_skip: usize, evals: &[F]) -> Self
pub fn from_evaluations(l_skip: usize, evals: &[F]) -> Self
Create PLE from evaluations on the hyperprism D x H_n for n >= 0.
Takes evaluations at 2^{l_skip + n} points and converts them to coefficient form for a polynomial in n+1 variables: degree < 2^l_skip in the first variable, degree < 2 (linear) in the other n variables.
The input evals should have length 2^{l_skip + n}.
The evaluation at index i corresponds to:
- bits 0 to l_skip-1: univariate point index
- bits l_skip to l_skip+n-1: multilinear variable assignments
pub fn eval_at_point<EF: ExtensionField<F>>( &self, l_skip: usize, z: EF, x: &[EF], ) -> EF
pub fn into_coeffs(self) -> Vec<F>